# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-16 07:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0023_userexamrecord_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='grade',
            name='coin',
            field=models.IntegerField(default=0, verbose_name='\u8003\u7ea7\u6d88\u8017M\u5e01'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 06:15
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0003_auto_20180112_1821'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='UserExam',
            new_name='UserExamRecord',
        ),
        migrations.RenameField(
            model_name='userexamrecord',
            old_name='grade_title',
            new_name='grade_name',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-25 03:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0018_userexamrecord_cert'),
    ]

    operations = [
        migrations.AddField(
            model_name='userexamrecord',
            name='year',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u5e74\u5ea6'),
        ),
        migrations.AlterField(
            model_name='gradecertfield',
            name='font_color',
            field=models.CharField(default='#000000', max_length=7, verbose_name='\u5b57\u4f53\u989c\u8272'),
        ),
        migrations.AlterField(
            model_name='gradecertfield',
            name='font_size',
            field=models.IntegerField(default=20, verbose_name='\u5b57\u4f53\u5927\u5c0f'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-


__author__ = 'bee'

from django.contrib.auth import get_user_model
from .models import UserExamRecord, UserStartExam

User = get_user_model()


#
#
# # django前台显示本地时间
# def filter_local_datetime(_datetime):
#     return _datetime
#
#
# # 学生报名后续操作
# def after_user_exam_add(record):
#     return True, ""
#
#
# # 学生报名前操作
# def before_user_exam(user_id):
#     return True, ""
#
#
# # 通过考级后操作
# def after_user_passed(record):
#     return True, ""


# # 是否开启了考级
# def get_is_start_exam(user):
#     if not user:
#         return None
#     record_list = UserStartExam.objects.filter(user=user, is_start_exam=True)
#     if record_list.exists():
#         return True
#     return False


def get_user_icon(user_id):
    if not user_id:
        return None
    record_list = UserExamRecord.objects.filter(user__id=user_id, status=1).order_by("-created_at")
    if record_list.count() >= 1:
        record = record_list.first()
        try:
            icon = record.grade.icon
            return icon.url
        except:
            return None
    else:
        return None


# 获取最近一次通过的的考级名称
def get_user_lasteat_exam_grade_name(user_id):
    if not user_id:
        return None
    record_list = UserExamRecord.objects.filter(user__id=user_id, status=1).order_by("-created_at")
    if record_list.count() >= 1:
        record = record_list.first()
        return record.grade_name
    else:
        return ""






# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-19 07:20
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0011_auto_20180118_1719'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='grade',
            name='cert_image',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-12 09:45
from __future__ import unicode_literals

from django.conf import settings
import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Grade',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u8003\u7ea7\u540d\u79f0')),
                ('order_by', models.IntegerField(blank=True, default=0, verbose_name='\u987a\u5e8f')),
                ('is_show', models.BooleanField(default=True, verbose_name='\u662f\u5426\u663e\u793a')),
                ('cert_image', models.ImageField(null=True, storage=django.core.files.storage.FileSystemStorage(location=b'media/exam_cert'), upload_to=b'')),
            ],
            options={
                'ordering': ['order_by'],
                'db_table': 'bee_django_exam_grade',
            },
        ),
        migrations.CreateModel(
            name='UserExam',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('grade_title', models.CharField(max_length=180, null=True)),
                ('created_at', models.DateTimeField(null=True)),
                ('is_passed', models.BooleanField(default=False)),
                ('result', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6210\u7ee9')),
                ('info', models.TextField(blank=True, null=True, verbose_name='\u5176\u4ed6')),
                ('grade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bee_django_exam_grade', to='bee_django_exam.Grade')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bee_django_exam_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_exam_user_exam',
            },
        ),
    ]
